@@ -6,7 +6,7 @@ library(brickster)
 test_that("DatabricksSQL driver can be created", {
   drv <- DatabricksSQL()
   expect_s4_class(drv, "DatabricksDriver")
-  expect_true(is(drv, "DBIDriver"))
+  expect_s4_class(drv, "DBIDriver")
 })
 
 test_that("DatabricksSQL driver show method works", {
@@ -18,14 +18,27 @@ test_that("Connection parameter validation works offline", {
   drv <- DatabricksSQL()
 
   # Test missing warehouse_id
-  expect_error(dbConnect(drv), "warehouse_id must be provided")
+  expect_error(
+    dbConnect(drv),
+    "warehouse_id or http_path must be provided"
+  )
   expect_error(
     dbConnect(drv, warehouse_id = ""),
-    "warehouse_id must be provided"
+    "warehouse_id or http_path must be provided"
   )
   expect_error(
     dbConnect(drv, warehouse_id = NULL),
-    "warehouse_id must be provided"
+    "warehouse_id or http_path must be provided"
+  )
+
+  # Test conflicting warehouse_id and http_path
+  expect_error(
+    dbConnect(
+      drv,
+      warehouse_id = "fake_id",
+      http_path = "/sql/warehouses/fake_id"
+    ),
+    "Specify only one of warehouse_id or http_path"
   )
 
   # Test with invalid credentials (should fail at connection test)
@@ -68,6 +81,17 @@ test_that("DatabricksConnection validation methods work", {
   expect_equal(info$host, "test_host")
 })
 
+test_that("Warehouse ID can be parsed from http_path", {
+  expect_equal(
+    warehouse_id_from_http_path("/sql/1.0/warehouses/30d6e63b35f828c5"),
+    "30d6e63b35f828c5"
+  )
+  expect_error(
+    warehouse_id_from_http_path(NULL),
+    "http_path must be provided and non-empty"
+  )
+})
+
 test_that("DatabricksConnection with invalid parameters fails validation", {
   # Empty warehouse_id
   con_invalid <- new(
@@ -129,16 +153,44 @@ test_that("Transaction restrictions work offline", {
 })
 
 test_that("Quote handling utility functions work", {
-  clean_quoted <- function(name) gsub('^"|"$', '', name)
+  clean_quoted <- brickster:::db_clean_table_name
 
   expect_equal(clean_quoted("table_name"), "table_name")
   expect_equal(clean_quoted('"table_name"'), "table_name")
-  expect_equal(clean_quoted('catalog.schema.table'), "catalog.schema.table")
+  expect_equal(clean_quoted("catalog.schema.table"), "catalog.schema.table")
   expect_equal(clean_quoted('"catalog.schema.table"'), "catalog.schema.table")
-  expect_equal(clean_quoted('samples.nyctaxi.trips'), "samples.nyctaxi.trips")
+  expect_equal(clean_quoted("samples.nyctaxi.trips"), "samples.nyctaxi.trips")
   expect_equal(clean_quoted('"samples.nyctaxi.trips"'), "samples.nyctaxi.trips")
 })
 
+test_that("db_prepare_create_table_fields handles inputs", {
+  fields <- c(id = "INT", name = "STRING")
+  result <- brickster:::db_prepare_create_table_fields(fields)
+
+  expect_s3_class(result$value, "data.frame")
+  expect_named(result$value, names(fields))
+  expect_shape(result$value, nrow = 0)
+  expect_equal(result$field_types, fields)
+
+  df_fields <- data.frame(id = integer(), name = character())
+  result <- brickster:::db_prepare_create_table_fields(df_fields)
+  expect_equal(result$value, df_fields)
+  expect_null(result$field_types)
+
+  expect_error(
+    brickster:::db_prepare_create_table_fields(NULL),
+    "fields must be provided"
+  )
+  expect_error(
+    brickster:::db_prepare_create_table_fields(character()),
+    "fields must contain at least one column"
+  )
+  expect_error(
+    brickster:::db_prepare_create_table_fields(c("INT", "STRING")),
+    "named character vector"
+  )
+})
+
 test_that("db_generate_typed_values_sql preserves single quotes", {
   con <- new(
     "DatabricksConnection",
@@ -247,7 +299,7 @@ test_that("DatabricksResult edge cases work offline", {
   # Fetch on completed result should return empty data frame
   empty_result <- dbFetch(res)
   expect_s3_class(empty_result, "data.frame")
-  expect_equal(nrow(empty_result), 0)
+  expect_shape(empty_result, nrow = 0)
 })
 
 # Online Tests (require warehouse connection) --------------------------------
@@ -282,7 +334,7 @@ test_that("DBI connection can be created with valid warehouse_id", {
 
   con <- dbConnect(drv, warehouse_id = test_warehouse_id)
   expect_s4_class(con, "DatabricksConnection")
-  expect_true(is(con, "DBIConnection"))
+  expect_s4_class(con, "DBIConnection")
   expect_true(dbIsValid(con))
 
   # Clean up
@@ -298,7 +350,7 @@ test_that("DBI connection info is correct", {
   expect_type(info, "list")
   expect_equal(info$warehouse_id, test_warehouse_id)
   expect_equal(info$db.version, "Databricks SQL")
-  expect_true(is.character(info$host))
+  expect_type(info$host, "character")
 
   dbDisconnect(con)
 })
@@ -330,7 +382,7 @@ test_that("dbGetQuery works for simple queries", {
   # Test simple query
   result <- dbGetQuery(con, "SELECT 1 as test_col", show_progress = FALSE)
   expect_s3_class(result, "data.frame")
-  expect_equal(nrow(result), 1)
+  expect_shape(result, nrow = 1)
   expect_equal(result$test_col, 1)
 
   # Test more complex query
@@ -339,8 +391,8 @@ test_that("dbGetQuery works for simple queries", {
     "SELECT 1 as a, 'test' as b, 3.14 as c",
     show_progress = FALSE
   )
-  expect_equal(nrow(result), 1)
-  expect_equal(ncol(result), 3)
+  expect_shape(result, nrow = 1)
+  expect_shape(result, ncol = 3)
   expect_equal(result$a, 1)
   expect_equal(result$b, "test")
   expect_equal(result$c, 3.14)
@@ -356,7 +408,7 @@ test_that("dbSendQuery and dbFetch work correctly", {
   # Test async query execution
   res <- dbSendQuery(con, "SELECT 1 as test_col")
   expect_s4_class(res, "DatabricksResult")
-  expect_true(is(res, "DBIResult"))
+  expect_s4_class(res, "DBIResult")
 
   # Initially not completed (async)
   expect_false(res@completed)
@@ -364,7 +416,7 @@ test_that("dbSendQuery and dbFetch work correctly", {
   # Fetch results
   result <- dbFetch(res)
   expect_s3_class(result, "data.frame")
-  expect_equal(nrow(result), 1)
+  expect_shape(result, nrow = 1)
   expect_equal(result$test_col, 1)
 
   # Should be completed after fetch
@@ -517,7 +569,7 @@ test_that("DatabricksResult methods work with empty results", {
   result <- dbFetch(res)
 
   expect_s3_class(result, "data.frame")
-  expect_equal(nrow(result), 0)
+  expect_shape(result, nrow = 0)
 
   dbClearResult(res)
   dbDisconnect(con)
@@ -533,7 +585,7 @@ test_that("Field discovery works with information_schema tables", {
   # Test field discovery on information_schema.tables
   expect_no_error({
     fields <- dbListFields(con, "information_schema.tables")
-    expect_true(is.character(fields))
+    expect_type(fields, "character")
     expect_true(length(fields) > 0)
     expect_true("table_name" %in% tolower(fields) || "tableName" %in% fields)
   })
@@ -555,9 +607,9 @@ test_that("Field discovery query returns correct structure", {
   )
 
   expect_s3_class(result, "data.frame")
-  expect_equal(nrow(result), 0) # Should have no rows
-  expect_equal(ncol(result), 3) # Should have 3 columns
-  expect_equal(names(result), c("col1", "col2", "col3"))
+  expect_shape(result, nrow = 0) # Should have no rows
+  expect_shape(result, ncol = 3) # Should have 3 columns
+  expect_named(result, c("col1", "col2", "col3"))
 
   dbDisconnect(con)
 })
