@@ -4,7 +4,7 @@ test_that("databricks helpers - runtime detection", {
     new = c(DATABRICKS_RUNTIME_VERSION = ""),
     {
       expect_no_error(on_databricks())
-      expect_identical(on_databricks(), FALSE)
+      expect_false(on_databricks())
       expect_identical(determine_brickster_venv(), "r-brickster")
 
     }
@@ -14,7 +14,7 @@ test_that("databricks helpers - runtime detection", {
     new = c(DATABRICKS_RUNTIME_VERSION = "14.0"),
     {
       expect_no_error(on_databricks())
-      expect_identical(on_databricks(), TRUE)
+      expect_true(on_databricks())
       expect_null(determine_brickster_venv())
 
     }
